#[non_exhaustive]pub enum ClientError {
DaemonUnavailable {
socket_path: PathBuf,
source: Error,
},
Protocol {
source: ProtocolError,
},
ErrorResponse {
code: ErrorCode,
message: String,
},
SpawnConflict(Box<SpawnConflictPayload>),
UnexpectedResponse {
expected: &'static str,
got: &'static str,
},
}Expand description
Error returned by the rtmd client.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
The configured daemon socket could not be reached.
Protocol
The daemon or transport returned malformed protocol data.
Fields

source: ProtocolErrorUnderlying protocol error.
ErrorResponse
The daemon returned an explicit error response.
SpawnConflict(Box<SpawnConflictPayload>)
The daemon refused a spawn because the requested identity or pane is already occupied.
UnexpectedResponse
A typed helper received a different response variant than expected.
Implementations