RuntimeClient

Struct RuntimeClient 

pub struct RuntimeClient { /* private fields */ }
Async client for the rtmd Unix socket JSON line protocol.

Implementations

Source

impl RuntimeClient

pub fn new(socket_path: impl Into<PathBuf>) -> Self

Create a client connected to socket_path.

pub fn socket_path(&self) -> &Path

Return the Unix socket path this client connects to.

pub async fn request( &self, rpc: RuntimeRpc, ) -> Result<RuntimeResponse, ClientError>

Send a raw protocol request and return the raw protocol response.

pub async fn spawn( &self, request: SpawnRequest, ) -> Result<SpawnedPayload, ClientError>

Spawn a runtime session and return the created lifecycle payload.

pub async fn kill( &self, request: KillRequest, ) -> Result<KillOutcome, ClientError>

Kill a runtime session by session id.

pub async fn kill_by_pid( &self, request: KillByPidRequest, ) -> Result<KillOutcome, ClientError>

Kill an arbitrary process id through the daemon admin path.

pub async fn status( &self, filter: StatusFilter, ) -> Result<StatusPayload, ClientError>

Query runtime lifecycle status.

pub async fn nudge( &self, request: NudgeRequest, ) -> Result<NudgeResponse, ClientError>

Send a text nudge to a runtime session and return the delivery outcome.

pub async fn capture( &self, request: CaptureRequest, ) -> Result<CaptureResponse, ClientError>

Capture scrollback for a runtime session.

pub async fn validate_target( &self, target: &str, ) -> Result<ValidateTargetResponse, ClientError>

Validate a user supplied spawn target string.

pub async fn doctor(&self) -> Result<DoctorPayload, ClientError>

Query daemon diagnostics.

pub async fn version(&self) -> Result<VersionPayload, ClientError>

Query the daemon version and protocol capability payload.

pub async fn events( &self, request: EventsRequest, ) -> Result<EventBatch, ClientError>

Query one batch of lifecycle events.